@@ -15,19 +15,20 @@ library(MoEClust)
 
 ## ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 data(CO2data)
-GNP   <- CO2data[,1]
-CO2   <- CO2data[,2]
+CO2   <- CO2data$CO2
+GNP   <- CO2data$GNP
 
 ## ---- results='hide'-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-m1    <- MoE_clust(CO2, G=0:2, verbose=FALSE)
-m2    <- MoE_clust(CO2, G=2,   gating= ~ GNP, verbose=FALSE)
-m3    <- MoE_clust(CO2, G=1:2, expert= ~ GNP, verbose=FALSE)
-m4    <- MoE_clust(CO2, G=2,   gating= ~ GNP, expert= ~ GNP, verbose=FALSE)
-m5    <- MoE_clust(CO2, G=2,   equalPro=TRUE, verbose=FALSE)
-m6    <- MoE_clust(CO2, G=2,   expert= ~ GNP, equalPro=TRUE, verbose=FALSE)
+m1    <- MoE_clust(CO2, G=1:3, verbose=FALSE)
+m2    <- MoE_clust(CO2, G=2:3, gating= ~ GNP, verbose=FALSE)
+m3    <- MoE_clust(CO2, G=1:3, expert= ~ GNP, verbose=FALSE)
+m4    <- MoE_clust(CO2, G=2:3, gating= ~ GNP, expert= ~ GNP, verbose=FALSE)
+m5    <- MoE_clust(CO2, G=2:3, equalPro=TRUE, verbose=FALSE)
+m6    <- MoE_clust(CO2, G=2:3, expert= ~ GNP, equalPro=TRUE, verbose=FALSE)
+m7    <- MoE_clust(CO2, G=2:3, expert= ~ GNP, tau0=0.1, verbose=FALSE)
 
 ## ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-(comp <- MoE_compare(m1, m2, m3, m4, m5, m6, pick=5))
+(comp <- MoE_compare(m1, m2, m3, m4, m5, m6, m7, pick=7, optimal.only=TRUE))
 
 (best <- comp$optimal)
 
@@ -44,17 +45,17 @@ x.name <- names(res$net.covs)
 y.name <- names(res$data)
 x      <- as.matrix(res$net.covs)
 y      <- as.matrix(res$data)
-plot(x=x, y=y, main=substitute(atop(paste('CO'[2], " Data"), paste(Mname, ": ", rG, " components  (incl. expert network covariate: GNP)")), list(Mname=res$modelName, rG=G)), ylab=expression('CO'[2]), xlab="GNP", type="n")
-x.new  <- setNames(seq(par("usr")[1], par("usr")[2], length=1000), rep("GNP", 1000))
-y.new  <- setNames(seq(par("usr")[3], par("usr")[4], length=1000), rep("CO2", 1000))
+plot(x=x, y=y, main=substitute(atop(paste('CO'[2], " Data"), paste(Mname, " model, G=", rG, ", equal mixing proportions, incl. expert network covariate: GNP")), list(Mname=res$modelName, rG=G)), ylab=expression('CO'[2]), xlab="GNP", type="n", cex.main=0.95)
+x.new  <- setNames(seq(par("usr")[1], par("usr")[2], length=100), rep("GNP", 100))
+y.new  <- setNames(seq(par("usr")[3], par("usr")[4], length=100), rep("CO2", 100))
 grid   <- expand.grid(x.new, y.new)
 getden <- function(x, y, res) {
   sig  <- res$parameters$variance$modelName
   den  <- do.call(cbind, lapply(seq_len(G), function(k) dnorm(y, predict(expert[[k]], newdata=setNames(data.frame(x), names(x)[1]), type="response"), sqrt(ifelse(sig == "V", res$parameters$variance$sigmasq[k], res$parameters$variance$sigmasq)))))
-  apply(matrix(res$parameters$pro, nrow=length(x), ncol=G, byrow=TRUE) * den, 1, sum)
+  rowSums(matrix(res$parameters$pro, nrow=length(x), ncol=G, byrow=TRUE) * den)
 }
-mat    <- matrix(getden(grid[,1], grid[,2], res), length(x.new), length(y.new))
-image(x.new, y.new, mat, col=c("white", heat.colors(30)[30:1]), xlab="GNP", ylab=paste('CO'[2]), add=TRUE)
+mat    <- matrix(getden(grid[,1L], grid[,2L], res), length(x.new), length(y.new))
+image(x.new, y.new, mat, col=c("white", heat.colors(30L)[30L:1L]), xlab="GNP", ylab=paste('CO'[2]), add=TRUE)
 box(lwd=1)
 contour(x.new, y.new, mat, add=TRUE, col="lightgray")
 points(GNP, CO2)
@@ -69,7 +70,7 @@ as.vector(predict(comp$optimal)$y)
 
 ## ---- results="hide"-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ind     <- sample(1:nrow(CO2data), 2)
-res2    <- MoE_clust(CO2data[-ind,]$CO2, G=2, expert=~GNP, network.data=CO2data[-ind,])
+res2    <- MoE_clust(CO2data[-ind,]$CO2, G=3, expert=~GNP, equalPro=TRUE, network.data=CO2data[-ind,])
 
 ## ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 predict(res2, newdata= list(new.x=CO2data[ind,"GNP", drop=FALSE])) # Using new covariates only
@@ -80,11 +81,11 @@ predict(res2, newdata = CO2data[ind,])         # Using both new covariates & new
 data(ais)
 hema  <- ais[,3:7]
 
-## ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-?MoE_control
+## ---- eval=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  ?MoE_control
 
 ## ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-mod   <- MoE_clust(hema, G=1:3, expert= ~ sex, gating= ~ BMI, network.data=ais)
+mod   <- MoE_clust(hema, G=1:3, expert= ~ sex, gating= ~ BMI, network.data=ais, tau0=0.1, noise.gate=FALSE)
 
 ## ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 plot(mod, what="gpairs")
@@ -105,22 +106,26 @@ plot(mod, what="uncertainty", type="profile")
 plot(mod, what="criterion", legendArgs=list(cex=0.8))
 
 ## ---- eval=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  plot(mod, what="gating")
+#  plot(mod, what="gating", x.axis=ais$BMI, type="p", xlab="BMI", pch=1)
+
+## ---- echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+plot(mod, what="gating", x.axis=ais$BMI, type="p", xlab="BMI", pch=1)
+
+## ---- eval=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  plot(mod, what="loglik")
 
 ## ---- echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-plot(mod, what="gating")
 plot(mod, what="loglik")
 
 ## ---- eval=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  require("lattice")
-#  z <- factor(mod$classification, labels=paste0("Cluster", seq_len(mod$G)))
+#  z <- factor(mod$classification[mod$classification > 0], labels=paste0("Cluster", seq_len(mod$G)))
 #  splom(~ hema | ais$sex, groups=z)
 #  splom(~ hema | z, groups=ais$sex)
 
 ## ---- echo=FALSE, fig.height=4-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 require("lattice")
-z <- factor(mod$classification, labels=paste0("Cluster", seq_len(mod$G)))
+z <- factor(mod$classification[mod$classification > 0], labels=paste0("Cluster", seq_len(mod$G)))
 splom(~ hema | ais$sex, groups=z, xlab=NULL)
 splom(~ hema | z, groups=ais$sex, xlab=NULL)
 
